"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.dSockCloudClient = exports.dSockClient = void 0;
const axios_1 = require("axios");
const errors_1 = require("./errors");
class dSockClient {
    /**
     * @param baseUrl The dSock API endpoint (without trailing slash)
     * @param token The dSock API token (to authorize requests)
     */
    constructor(baseUrl, token) {
        this.axios = axios_1.default.create({
            baseURL: baseUrl,
            headers: {
                Authorization: `Bearer ${token}`,
            },
        });
    }
    createClaim(options) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: "/claim",
                method: "POST",
                params: Object.assign({ user: options.user, session: options.session, id: options.id, channels: (_a = options.channels) === null || _a === void 0 ? void 0 : _a.join(",") }, options.time),
            });
        });
    }
    send(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: "/send",
                method: "POST",
                data: options.data,
                params: {
                    user: options.user,
                    session: options.session,
                    id: options.id,
                    channel: options.channel,
                    type: Buffer.isBuffer(options.data) ? "binary" : "text",
                },
            });
        });
    }
    disconnect(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: "/disconnect",
                method: "POST",
                params: {
                    user: options.user,
                    session: options.session,
                    id: options.id,
                    channel: options.channel,
                    keepClaims: options.keepClaims,
                },
            });
        });
    }
    info(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: "/info",
                method: "GET",
                params: {
                    user: options.user,
                    session: options.session,
                    id: options.id,
                    channel: options.channel,
                },
            });
        });
    }
    channelSubscribe(channel, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: `/channel/subscribe/${channel}`,
                method: "POST",
                params: {
                    user: options.user,
                    session: options.session,
                    id: options.id,
                    channel: options.channel,
                },
            });
        });
    }
    channelUnsubscribe(channel, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.request({
                url: `/channel/unsubscribe/${channel}`,
                method: "POST",
                params: {
                    user: options.user,
                    session: options.session,
                    id: options.id,
                    channel: options.channel,
                },
            });
        });
    }
    request(options) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.axios.request(Object.assign(Object.assign({}, options), { validateStatus: () => true }));
            const metadata = {
                url: options.url,
                baseUrl: options.baseURL,
                method: options.method,
                params: options.params,
                statusCode: response.status,
                headers: response.headers,
            };
            if (!((_a = response.headers["content-type"]) === null || _a === void 0 ? void 0 : _a.includes("application/json"))) {
                throw new errors_1.dSockApiError(response.status.toString(), `Did not receive JSON (${response.headers["content-type"]})`, metadata);
            }
            if (response.data.success === false) {
                throw new errors_1.dSockApiError(response.data.errorCode, response.data.error, metadata);
            }
            if (response.status >= 400) {
                throw new errors_1.dSockApiError(response.status.toString(), response.statusText, metadata);
            }
            return response.data;
        });
    }
}
exports.dSockClient = dSockClient;
class dSockCloudClient extends dSockClient {
    /**
     * @param projectId The dSock Cloud project ID
     * @param key The dSock Cloud project key
     */
    constructor(projectId, key) {
        super(`https://api.dsock.cloud/${projectId}`, key);
    }
}
exports.dSockCloudClient = dSockCloudClient;
//# sourceMappingURL=index.js.map